# Contribute to This Plugin

Contributions to the development of the catalysis plugin are highly welcome. If you have example datasets you want to publish or general feedback and suggestions to improve the plugin, please get in touch by opening an issue in the plugin repository or sending and email.

# Contribute to the documentation

If you want to contribute to the documentation, please create an issue in the repo or get in touch with the authors.

